PrimitiveReader

Struct PrimitiveReader 

pub struct PrimitiveReader<R> { /* private fields */ }
Primitive store reader utility.

Implementations

Source

impl<R> PrimitiveReader<R>

pub fn into_inner(self) -> R

Consume the primitive reader and

Source

impl<R: Read + Seek> PrimitiveReader<R>

pub fn open(inner: R) -> Result<Self, DeError>

Open and decode a prititives file’s header, the reader is kept open and date can be read.

The position of the reader is not important because it will be forced to zero before reading. It works like that because the inner reader will be read in absolute positionning.

pub fn iter_sections_meta(&self) -> impl Iterator<Item = &SectionMeta>

pub fn get_section_meta(&self, name: &str) -> Option<&SectionMeta>

pub fn read_section<S: Section>( &mut self, name: &str, ) -> Option<Result<S, DeError>>

Read the given section using the given section type.