ElementReader

Enum ElementReader 

pub enum ElementReader<'reader, 'bundle> {
    Top(TopElementReader<'reader, 'bundle>),
    Reply(ReplyElementReader<'reader, 'bundle>),
}
Bundle element variant iterated from BundleElementIter. This enum provides a better way to read replies using sub codecs.

Variants



Top(TopElementReader<'reader, 'bundle>)

A top element with a proper ID and a reader.



Reply(ReplyElementReader<'reader, 'bundle>)

A reply element with request ID and a reader.

Implementations

Source

impl ElementReader<'_, '_>

pub fn is_simple(&self) -> bool

Return true if this element is a simple one.

pub fn is_reply(&self) -> bool

Return true if this element is a reply.