Bundle

Struct Bundle 

pub struct Bundle { /* private fields */ }
A bundle is a sequence of packets that are used to store elements. Elements of various types, like regular elements, requests or replies can be simply added and the number of packets contained in this bundle is automatically adjusted if no more space is available.

Functions that are used to add elements provide a builder-like structure by returning a mutable reference to itself.

Implementations

Source

impl Bundle

pub fn new() -> Bundle

Construct a new empty bundle, this bundle doesn’t allocate until you add the first element.

pub fn with_single(packet: Box<Packet>) -> Self

Create a new bundle with one predefined packet.

pub fn with_multiple(packets: Vec<Box<Packet>>) -> Self

Create a new bundle with multiple predefined packets.

pub fn element_reader(&self) -> BundleElementReader<'_>

pub fn element_writer(&mut self) -> BundleElementWriter<'_>

pub fn len(&self) -> usize

Return the number of packets in this bundle.

pub fn is_empty(&self) -> bool

pub fn clear(&mut self)

Clear the bundle by removing all packets.

pub fn packets(&self) -> &[Box<Packet>]

Get a slice of all packets of this bundle.

pub fn packets_mut(&mut self) -> &mut [Box<Packet>]