BundleElementWriter

Struct BundleElementWriter 

pub struct BundleElementWriter<'a> { /* private fields */ }
The structure used to write elements to a bundle. This structure

Implementations

Source

impl<'a> BundleElementWriter<'a>

pub fn write<E: TopElement>(&mut self, id: u8, element: E, config: &E::Config)

Add an element to this bundle.

pub fn write_simple<E: TopElement<Config = ()>>(&mut self, id: u8, element: E)

Add a simple element to this bundle. Such elements have no config.

pub fn write_request<E: TopElement>( &mut self, id: u8, element: E, config: &E::Config, request_id: u32, )

Add a request element to this bundle, with a given request ID.

pub fn write_simple_request<E: TopElement<Config = ()>>( &mut self, id: u8, element: E, request_id: u32, )

Add a request element to this bundle, with a given request ID. Such elements have no config.

pub fn write_reply<E: Element>( &mut self, element: E, config: &E::Config, request_id: u32, )

Add a reply element to this bundle, for a given request ID.

Such elements are special and don’t require an ID, because they are always of a 32-bit variable length and prefixed with the request ID.

pub fn write_simple_reply<E: Element<Config = ()>>( &mut self, element: E, request_id: u32, )

Add a reply element to this bundle, for a given request ID. Such elements have no config.

pub fn write_raw<E: TopElement>( &mut self, element: BundleElement<E>, config: &E::Config, )

Raw method to add an element to this bundle, given an ID, the element and its config. With an optional request ID.