ReplyElementReader

Struct ReplyElementReader 

pub struct ReplyElementReader<'reader, 'bundle>(/* private fields */);
The reply variant of element, provides a way to read replies and get Reply elements containing the final element.

Implementations

Source

impl<'reader, 'bundle> ReplyElementReader<'reader, 'bundle>

pub fn request_id(&self) -> u32

Get the request id this reply is for.

pub fn read_stable<E: Element>( &mut self, config: &E::Config, ) -> BundleResult<BundleElement<E>>

Same as read but never go to the next element (this is why this method doesn’t take self by value).

This method doesn’t returns the reply element but the final element.

pub fn read_simple_stable<E: Element<Config = ()>>( &mut self, ) -> BundleResult<BundleElement<E>>

pub fn read<E: Element>( self, config: &E::Config, ) -> BundleResult<BundleElement<E>>

Read the reply element using the given codec. This method take self by value and automatically go the next element if read is successful, if not successful you will need to call Bundle::next_element again.

This method doesn’t returns the reply element but the final element.

pub fn read_simple<E: Element<Config = ()>>( self, ) -> BundleResult<BundleElement<E>>