CreateBasePlayer

Struct CreateBasePlayer 

pub struct CreateBasePlayer<E> {
    pub entity_id: u32,
    pub entity_type: u16,
    pub unk: String,
    pub entity_data: E,
    pub entity_components_count: u8,
}
Sent from the base when a player should be created, the entity id is given with its type.

The remaining data will later be decoded properly depending on the entity type, it’s used for initializing its properties (TODO). For example the Login entity receive the account UID.

Fields

entity_id: u32

The unique identifier of the entity being created.

entity_type: u16

The entity type identifier being created.

unk: String

This string’s usage is currently unknown.

entity_data: E

The actual data to be sent for creating the player’s entity.

entity_components_count: u8

This integer describe the number of entity components composing the entity, this value must be strictly equal to the same value as the client.

TODO: This number is used to know how much entity components must be parsed after this number. Components can be seen as regular components. It’s not currently implemented.