pub struct ForcedPosition {
pub entity_id: u32,
pub space_id: u32,
pub vehicle_entity_id: u32,
pub position: Vec3A,
pub direction: Vec3A,
}Expand description
This is when an update is being forced back for an (ordinarily) client controlled entity, including for the player. Usually this is due to a physics correction from the server, but it could be for any reason decided by the server (e.g. server-initiated teleport).
Fields
entity_id: u32space_id: u32vehicle_entity_id: u32position: Vec3Adirection: Vec3ATrait Implementations
Sourceimpl Clone for ForcedPosition
impl Clone for ForcedPosition
Sourcefn clone(&self) -> ForcedPosition
fn clone(&self) -> ForcedPosition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForcedPosition
impl Debug for ForcedPosition