UpdateFrequencyNotification

Struct UpdateFrequencyNotification 

pub struct UpdateFrequencyNotification {
    pub frequency: u8,
    pub game_time: u32,
}
The server informs us how frequently it is going to send update the the client, and also give the server game time (exactly the same as SetGameTime element, but inlined here).

Fields

frequency: u8

The frequency in hertz.

game_time: u32

The server game time.