MethodCallWrapper

Struct MethodCallWrapper 

pub struct MethodCallWrapper<M, P>{
    pub method: M,
    pub ext: P,
}
This special bundle’s element can be used to call a method either on the server or on the client. Its interface is quite complicated, so it’s only internal and must be used through public functions.

Fields

method: M

The actual wrapped method call.

ext: P

The extension element that is encoded or decoded just before the actual method call.

Implementations

Source

impl<M, P> MethodCallWrapper<M, P>

pub const DEFAULT_LEN: ElementLength

The length type to use if now particular length is required, this length defaults to a callback which returns a length depending on the id and the use of sub-slot to represent the method’s id.

pub fn new(method: M, prefix: P) -> Self

pub fn write(self, writer: BundleElementWriter<'_>)

pub fn read( reader: TopElementReader<'_, '_>, ) -> BundleResult<BundleElement<Self>>