pub enum LoginRequestEncryption {
Clear,
Client(Arc<RsaPublicKey>),
Server(Arc<RsaPrivateKey>),
}Expand description
Describe the type of encryption to use for encoding/decoding a login request. This must be provided as configuration when writing or reading the element.
Variants
Clear
Clear transmission between server and client.
Client(Arc<RsaPublicKey>)
Encrypted encoding.
Server(Arc<RsaPrivateKey>)
Encrypted decoding.