LoginResponseEncryption

Enum LoginResponseEncryption 

pub enum LoginResponseEncryption {
    Clear,
    Encrypted(Arc<Blowfish>),
}
Describe if the login response has to be encrypted or not. This must be provided as configuration when writing or reading the element.

Variants



Clear

The login response is not encrypted. This should be selected if the login request contains an empty blowfish key.



Encrypted(Arc<Blowfish>)

The login response is encrypted with the given blowfish key. This blowfish key should be created from the key provided by the client in the login request.

The blowfish key is only actually used when encoding or decoding a login success, other statuses do not require the key.