ElementIdRange

Struct ElementIdRange 

pub struct ElementIdRange {
    pub first: u8,
    pub last: u8,
}
An utility structure for storing ranges of element’s ids. It provides way of converting between element id (with optional sub-id) and exposed id.

This structure is small and therefore can be copied.

Fields

first: u8last: u8

Implementations

Source

impl ElementIdRange

pub const fn new(first: u8, last: u8) -> Self

pub const fn slots_count(self) -> u8

Returns the number of slots in this range.

pub const fn sub_slots_count(self, exposed_count: u16) -> u8

Returns the number of slots that requires a sub-id. These slots are starting from the end of the range. For example, if this function returns 1, this means that the last slot (.last), if used, will be followed by a sub-id.

You must given the total number of exposed ids, because the presence of sub-id depends on how exposed ids can fit in the id range.

pub const fn full_slots_count(self, exposed_count: u16) -> u8

Returns the number of full slots that don’t require a sub-id. This is the opposite of sub_slots_count, read its documentation.

pub fn from_exposed_id( self, exposed_count: u16, exposed_id: u16, ) -> (u8, Option<u8>)

Get the element’s id and optional sub-id from the given exposed id and total count of exposed ids.

pub fn to_exposed_id_checked( self, exposed_count: u16, element_id: u8, ) -> Option<u16>

Get the exposed id from an element, but only return some exposed id if it fits into

pub fn to_exposed_id( self, exposed_count: u16, element_id: u8, sub_id_getter: impl FnOnce() -> u8, ) -> u16

Get the exposed id from an element id and optionally a sub-id, which should be lazily provided with a closure.