pub enum PacketConfigError {
UnknownFlags(u16),
Corrupted,
InvalidChecksum,
}Expand description
Packet error when reading invalid config from a packet.
Variants
UnknownFlags(u16)
Unknown flags are used, the packet can’t be decoded because this usually increase length of the footer.
Corrupted
The packet is corrupted, the footer might be too short or an invalid bit pattern has been read.
InvalidChecksum
The packet checksum and calculated checksum aren’t equal.