pub enum PacketRejectionError {
TimedOut,
InvalidEncryption,
Config(PacketConfigError),
}Expand description
Kind of error that caused a packet to be rejected from this socket and not received.
Variants
TimedOut
The packet is part of a sequence but no other packets of the sequence have been found and therefore no bundle can be reconstructed.
InvalidEncryption
The packet should be decrypted but it failed.
Config(PacketConfigError)
The packet could not be synchronized from its data.