pub enum Value {
Element(Box<Element>),
String(String),
Integer(i64),
Boolean(bool),
Float(f32),
Vec3(Vec3A),
Affine3(Affine3A),
}Expand description
A packed XML untyped value.
Variants
Element(Box<Element>)
String(String)
Integer(i64)
Boolean(bool)
Float(f32)
Vec3(Vec3A)
Affine3(Affine3A)
Implementations
Sourceimpl Value
impl Value
Sourcepub fn as_element(&self) -> Option<&Element>
pub fn as_element(&self) -> Option<&Element>
Try to get this value as an element if possible.
Sourcepub fn as_integer(&self) -> Option<i64>
pub fn as_integer(&self) -> Option<i64>
Try to get this value as an integer if possible.
Sourcepub fn as_boolean(&self) -> Option<bool>
pub fn as_boolean(&self) -> Option<bool>
Try to get this value as a boolean is possible.
Sourcepub fn as_affine3(&self) -> Option<Affine3A>
pub fn as_affine3(&self) -> Option<Affine3A>
Try to get this value as an affine3 is possible.