pub struct ResDirEntry { /* private fields */ }Expand description
Represent an file or directory entry returned by ResReadDir.
Implementations
Sourceimpl ResDirEntry
impl ResDirEntry
Sourcepub fn path(&self) -> String
pub fn path(&self) -> String
Reconstruct the full path of the entry for later ResFilesystem::read() call.