pub fn from_reader<R: Read + Seek>(reader: R) -> Result<Box<Visual>, DeError>
Try to read a visual processed file from a seekable reader.
The content will be read starting from the inital position of the writer.