pub struct BundleElement<E> {
pub id: u8,
pub element: E,
pub request_id: Option<u32>,
}Expand description
The full description of an element being read or to be written. Including its numeric identifier (0xFF if reply), the element itself and the optional request id.
Fields
id: u8Numeric identifier of the element.
element: EThe actual element. TODO: Rename to “payload”
request_id: Option<u32>The request ID if the element is a request. Not to be confused
with the reply ID if the element is a Reply.
Implementations
Sourceimpl<E> BundleElement<E>
impl<E> BundleElement<E>
Sourcepub fn map<U, F: FnOnce(E) -> U>(self, f: F) -> BundleElement<U>
pub fn map<U, F: FnOnce(E) -> U>(self, f: F) -> BundleElement<U>
Map this read element’s type into another one with the given closure.