TopElementReader

Struct TopElementReader 

pub struct TopElementReader<'reader, 'bundle>(/* private fields */);
The simple variant of element, provides direct decoding using a codec.

Implementations

Source

impl TopElementReader<'_, '_>

pub fn id(&self) -> u8

Get the numeric identifier of the element being read.

pub fn read_stable<E: TopElement>( &mut self, config: &E::Config, ) -> BundleResult<BundleElement<E>>

Same as read but never go to the next element (this is why this method doesn’t take self by value).

pub fn read_simple_stable<E: TopElement<Config = ()>>( &mut self, ) -> BundleResult<BundleElement<E>>

pub fn read<E: TopElement>( self, config: &E::Config, ) -> BundleResult<BundleElement<E>>

Read the element using the given codec. This method take self by value and automatically go the next element if read is successful, if not successful you will need to call Bundle::next_element again.

pub fn read_simple<E: TopElement<Config = ()>>( self, ) -> BundleResult<BundleElement<E>>