pub struct CellEntityMethod<M: MethodCall> {
pub entity_id: u32,
pub method: M,
}Expand description
Sent by the client to the base app to call a cell method for the given entity ID.
Fields
entity_id: u32The entity ID on which we’ll call the method, must be set to 0 if the current player is targeted.
method: MThe method call.
Implementations
Sourceimpl<M: MethodCall> CellEntityMethod<M>
impl<M: MethodCall> CellEntityMethod<M>
Sourcepub fn write(self, writer: BundleElementWriter<'_>)
pub fn write(self, writer: BundleElementWriter<'_>)
Write this cell entity method call to the given bundle.
Sourcepub fn read(
reader: TopElementReader<'_, '_>,
) -> BundleResult<BundleElement<Self>>
pub fn read( reader: TopElementReader<'_, '_>, ) -> BundleResult<BundleElement<Self>>
Read this cell entity method call from the given top element reader.