pub struct ClientAuth {
pub login_key: u32,
pub attempts_count: u8,
pub unk: u16,
}Expand description
Sent by the client to the server without encryption in order to authenticate, the server then compares with its internal login keys from past successful logins on the login app.
This element is usually a request, in such case a ServerSessionKey must be
sent as a reply.
Fields
login_key: u32The login key that was sent by the login application, part of the element
super::login::LoginSuccess.
attempts_count: u8The current number of attempts.
unk: u16Unknown 16-bits value at the end.