pub struct ServerSessionKey {
pub session_key: u32,
}Expand description
Replied by the server to the client when receiving a ClientAuth request
element. The key must be a new session
Fields
session_key: u32The server session key, should not be the same as the login session key.