pub struct MethodCallWrapper<M, P>where
M: MethodCall,
P: MethodCallExt,{
pub method: M,
pub ext: P,
}Expand description
This special bundle’s element can be used to call a method either on the server or on the client. Its interface is quite complicated, so it’s only internal and must be used through public functions.
Fields
method: MThe actual wrapped method call.
ext: PThe extension element that is encoded or decoded just before the actual method call.
Implementations
Sourceimpl<M, P> MethodCallWrapper<M, P>where
M: MethodCall,
P: MethodCallExt,
impl<M, P> MethodCallWrapper<M, P>where
M: MethodCall,
P: MethodCallExt,
Sourcepub const DEFAULT_LEN: ElementLength
pub const DEFAULT_LEN: ElementLength
The length type to use if now particular length is required, this length defaults to a callback which returns a length depending on the id and the use of sub-slot to represent the method’s id.
pub fn new(method: M, prefix: P) -> Self
pub fn write(self, writer: BundleElementWriter<'_>)
pub fn read( reader: TopElementReader<'_, '_>, ) -> BundleResult<BundleElement<Self>>