pub trait MethodCallExt: TopElement<Config = ()> {
const ID_RANGE: ElementIdRange;
}Expand description
Trait to implement on extension elements that is used together with
MethodCallWrapper to encode or decode generic method call elements.
Required Associated Constants
const ID_RANGE: ElementIdRange
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.