pub enum ElementLength {
Fixed(u32),
Variable8,
Variable16,
Variable24,
Variable32,
Callback(fn(id: u8) -> ElementLength),
}Expand description
Type of length used by a specific message codec. This describes how the length of an element should be encoded in the packet.
Variants
Fixed(u32)
A fixed length element, the length is not written in the header.
Variable8
The length is encoded on 8 bits in the element’s header.
Variable16
The length is encoded on 16 bits in the element’s header.
Variable24
The length is encoded on 24 bits in the element’s header.
Variable32
The length is encoded on 32 bits in the element’s header.
Callback(fn(id: u8) -> ElementLength)
The real length of the element is queried dynamically with a callback, given the element’s identifier.
Implementations
Sourceimpl ElementLength
impl ElementLength