pub struct ElementIdRange {
pub first: u8,
pub last: u8,
}Expand description
An utility structure for storing ranges of element’s ids. It provides way of converting between element id (with optional sub-id) and exposed id.
This structure is small and therefore can be copied.
Fields
first: u8last: u8Implementations
Sourceimpl ElementIdRange
impl ElementIdRange
pub const fn new(first: u8, last: u8) -> Self
Sourcepub const fn slots_count(self) -> u8
pub const fn slots_count(self) -> u8
Returns the number of slots in this range.
Sourcepub const fn sub_slots_count(self, exposed_count: u16) -> u8
pub const fn sub_slots_count(self, exposed_count: u16) -> u8
Returns the number of slots that requires a sub-id. These slots are
starting from the end of the range. For example, if this function
returns 1, this means that the last slot (.last), if used, will be
followed by a sub-id.
You must given the total number of exposed ids, because the presence of sub-id depends on how exposed ids can fit in the id range.
Sourcepub const fn full_slots_count(self, exposed_count: u16) -> u8
pub const fn full_slots_count(self, exposed_count: u16) -> u8
Returns the number of full slots that don’t require a sub-id. This
is the opposite of sub_slots_count, read its documentation.
Sourcepub fn from_exposed_id(
self,
exposed_count: u16,
exposed_id: u16,
) -> (u8, Option<u8>)
pub fn from_exposed_id( self, exposed_count: u16, exposed_id: u16, ) -> (u8, Option<u8>)
Get the element’s id and optional sub-id from the given exposed id and total count of exposed ids.