pub struct PackageFileReader<R: Read + Seek> { /* private fields */ }Expand description
A handle for reading a file in a package.
Implementations
Sourceimpl<R: Read + Seek> PackageFileReader<R>
impl<R: Read + Seek> PackageFileReader<R>
Sourcepub fn try_clone_with<NewR: Read + Seek>(
&mut self,
reader: NewR,
) -> Result<PackageFileReader<NewR>>
pub fn try_clone_with<NewR: Read + Seek>( &mut self, reader: NewR, ) -> Result<PackageFileReader<NewR>>
A fast copy of this package file reader. The caller must ensure that the new reader points to the same blob of data as the current one and has exact same seek boundaries. If not, this will result in incorrect yet safe data read.
This function immediately tries to seek to the same position, so it may error out if seek fails.
This method takes self as mutable reference because it needs to read the current seek position and it requires mutability.